/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package it.tref.liferay.mapit.map.service.base;

import com.liferay.portal.kernel.bean.BeanReference;
import com.liferay.portal.kernel.bean.IdentifiableBean;
import com.liferay.portal.kernel.dao.jdbc.SqlUpdate;
import com.liferay.portal.kernel.dao.jdbc.SqlUpdateFactoryUtil;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.dao.orm.DynamicQueryFactoryUtil;
import com.liferay.portal.kernel.dao.orm.Projection;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.search.Indexable;
import com.liferay.portal.kernel.search.IndexableType;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.model.PersistedModel;
import com.liferay.portal.service.BaseLocalServiceImpl;
import com.liferay.portal.service.PersistedModelLocalServiceRegistryUtil;
import com.liferay.portal.service.persistence.UserPersistence;

import it.tref.liferay.mapit.map.model.Plugin;
import it.tref.liferay.mapit.map.service.PluginLocalService;
import it.tref.liferay.mapit.map.service.persistence.PluginPersistence;
import it.tref.liferay.mapit.map.service.persistence.PluginPortletPreferencesPersistence;

import java.io.Serializable;

import java.util.List;

import javax.sql.DataSource;

/**
 * Provides the base implementation for the plugin local service.
 *
 * <p>
 * This implementation exists only as a container for the default service methods generated by ServiceBuilder. All custom service methods should be put in {@link it.tref.liferay.mapit.map.service.impl.PluginLocalServiceImpl}.
 * </p>
 *
 * @author
 * @see it.tref.liferay.mapit.map.service.impl.PluginLocalServiceImpl
 * @see it.tref.liferay.mapit.map.service.PluginLocalServiceUtil
 * @generated
 */
public abstract class PluginLocalServiceBaseImpl extends BaseLocalServiceImpl
	implements PluginLocalService, IdentifiableBean {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this class directly. Always use {@link it.tref.liferay.mapit.map.service.PluginLocalServiceUtil} to access the plugin local service.
	 */

	/**
	 * Adds the plugin to the database. Also notifies the appropriate model listeners.
	 *
	 * @param plugin the plugin
	 * @return the plugin that was added
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.REINDEX)
	@Override
	public Plugin addPlugin(Plugin plugin) throws SystemException {
		plugin.setNew(true);

		return pluginPersistence.update(plugin);
	}

	/**
	 * Creates a new plugin with the primary key. Does not add the plugin to the database.
	 *
	 * @param pluginId the primary key for the new plugin
	 * @return the new plugin
	 */
	@Override
	public Plugin createPlugin(long pluginId) {
		return pluginPersistence.create(pluginId);
	}

	/**
	 * Deletes the plugin with the primary key from the database. Also notifies the appropriate model listeners.
	 *
	 * @param pluginId the primary key of the plugin
	 * @return the plugin that was removed
	 * @throws PortalException if a plugin with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.DELETE)
	@Override
	public Plugin deletePlugin(long pluginId)
		throws PortalException, SystemException {
		return pluginPersistence.remove(pluginId);
	}

	/**
	 * Deletes the plugin from the database. Also notifies the appropriate model listeners.
	 *
	 * @param plugin the plugin
	 * @return the plugin that was removed
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.DELETE)
	@Override
	public Plugin deletePlugin(Plugin plugin) throws SystemException {
		return pluginPersistence.remove(plugin);
	}

	@Override
	public DynamicQuery dynamicQuery() {
		Class<?> clazz = getClass();

		return DynamicQueryFactoryUtil.forClass(Plugin.class,
			clazz.getClassLoader());
	}

	/**
	 * Performs a dynamic query on the database and returns the matching rows.
	 *
	 * @param dynamicQuery the dynamic query
	 * @return the matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery)
		throws SystemException {
		return pluginPersistence.findWithDynamicQuery(dynamicQuery);
	}

	/**
	 * Performs a dynamic query on the database and returns a range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query
	 * @param start the lower bound of the range of model instances
	 * @param end the upper bound of the range of model instances (not inclusive)
	 * @return the range of matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery, int start, int end)
		throws SystemException {
		return pluginPersistence.findWithDynamicQuery(dynamicQuery, start, end);
	}

	/**
	 * Performs a dynamic query on the database and returns an ordered range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query
	 * @param start the lower bound of the range of model instances
	 * @param end the upper bound of the range of model instances (not inclusive)
	 * @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	 * @return the ordered range of matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery, int start, int end,
		OrderByComparator orderByComparator) throws SystemException {
		return pluginPersistence.findWithDynamicQuery(dynamicQuery, start, end,
			orderByComparator);
	}

	/**
	 * Returns the number of rows that match the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query
	 * @return the number of rows that match the dynamic query
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public long dynamicQueryCount(DynamicQuery dynamicQuery)
		throws SystemException {
		return pluginPersistence.countWithDynamicQuery(dynamicQuery);
	}

	/**
	 * Returns the number of rows that match the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query
	 * @param projection the projection to apply to the query
	 * @return the number of rows that match the dynamic query
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public long dynamicQueryCount(DynamicQuery dynamicQuery,
		Projection projection) throws SystemException {
		return pluginPersistence.countWithDynamicQuery(dynamicQuery, projection);
	}

	@Override
	public Plugin fetchPlugin(long pluginId) throws SystemException {
		return pluginPersistence.fetchByPrimaryKey(pluginId);
	}

	/**
	 * Returns the plugin with the primary key.
	 *
	 * @param pluginId the primary key of the plugin
	 * @return the plugin
	 * @throws PortalException if a plugin with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public Plugin getPlugin(long pluginId)
		throws PortalException, SystemException {
		return pluginPersistence.findByPrimaryKey(pluginId);
	}

	@Override
	public PersistedModel getPersistedModel(Serializable primaryKeyObj)
		throws PortalException, SystemException {
		return pluginPersistence.findByPrimaryKey(primaryKeyObj);
	}

	/**
	 * Returns a range of all the plugins.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link it.tref.liferay.mapit.map.model.impl.PluginModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param start the lower bound of the range of plugins
	 * @param end the upper bound of the range of plugins (not inclusive)
	 * @return the range of plugins
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public List<Plugin> getPlugins(int start, int end)
		throws SystemException {
		return pluginPersistence.findAll(start, end);
	}

	/**
	 * Returns the number of plugins.
	 *
	 * @return the number of plugins
	 * @throws SystemException if a system exception occurred
	 */
	@Override
	public int getPluginsCount() throws SystemException {
		return pluginPersistence.countAll();
	}

	/**
	 * Updates the plugin in the database or adds it if it does not yet exist. Also notifies the appropriate model listeners.
	 *
	 * @param plugin the plugin
	 * @return the plugin that was updated
	 * @throws SystemException if a system exception occurred
	 */
	@Indexable(type = IndexableType.REINDEX)
	@Override
	public Plugin updatePlugin(Plugin plugin) throws SystemException {
		return pluginPersistence.update(plugin);
	}

	/**
	 * Returns the plugin local service.
	 *
	 * @return the plugin local service
	 */
	public it.tref.liferay.mapit.map.service.PluginLocalService getPluginLocalService() {
		return pluginLocalService;
	}

	/**
	 * Sets the plugin local service.
	 *
	 * @param pluginLocalService the plugin local service
	 */
	public void setPluginLocalService(
		it.tref.liferay.mapit.map.service.PluginLocalService pluginLocalService) {
		this.pluginLocalService = pluginLocalService;
	}

	/**
	 * Returns the plugin persistence.
	 *
	 * @return the plugin persistence
	 */
	public PluginPersistence getPluginPersistence() {
		return pluginPersistence;
	}

	/**
	 * Sets the plugin persistence.
	 *
	 * @param pluginPersistence the plugin persistence
	 */
	public void setPluginPersistence(PluginPersistence pluginPersistence) {
		this.pluginPersistence = pluginPersistence;
	}

	/**
	 * Returns the plugin portlet preferences local service.
	 *
	 * @return the plugin portlet preferences local service
	 */
	public it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalService getPluginPortletPreferencesLocalService() {
		return pluginPortletPreferencesLocalService;
	}

	/**
	 * Sets the plugin portlet preferences local service.
	 *
	 * @param pluginPortletPreferencesLocalService the plugin portlet preferences local service
	 */
	public void setPluginPortletPreferencesLocalService(
		it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalService pluginPortletPreferencesLocalService) {
		this.pluginPortletPreferencesLocalService = pluginPortletPreferencesLocalService;
	}

	/**
	 * Returns the plugin portlet preferences persistence.
	 *
	 * @return the plugin portlet preferences persistence
	 */
	public PluginPortletPreferencesPersistence getPluginPortletPreferencesPersistence() {
		return pluginPortletPreferencesPersistence;
	}

	/**
	 * Sets the plugin portlet preferences persistence.
	 *
	 * @param pluginPortletPreferencesPersistence the plugin portlet preferences persistence
	 */
	public void setPluginPortletPreferencesPersistence(
		PluginPortletPreferencesPersistence pluginPortletPreferencesPersistence) {
		this.pluginPortletPreferencesPersistence = pluginPortletPreferencesPersistence;
	}

	/**
	 * Returns the counter local service.
	 *
	 * @return the counter local service
	 */
	public com.liferay.counter.service.CounterLocalService getCounterLocalService() {
		return counterLocalService;
	}

	/**
	 * Sets the counter local service.
	 *
	 * @param counterLocalService the counter local service
	 */
	public void setCounterLocalService(
		com.liferay.counter.service.CounterLocalService counterLocalService) {
		this.counterLocalService = counterLocalService;
	}

	/**
	 * Returns the resource local service.
	 *
	 * @return the resource local service
	 */
	public com.liferay.portal.service.ResourceLocalService getResourceLocalService() {
		return resourceLocalService;
	}

	/**
	 * Sets the resource local service.
	 *
	 * @param resourceLocalService the resource local service
	 */
	public void setResourceLocalService(
		com.liferay.portal.service.ResourceLocalService resourceLocalService) {
		this.resourceLocalService = resourceLocalService;
	}

	/**
	 * Returns the user local service.
	 *
	 * @return the user local service
	 */
	public com.liferay.portal.service.UserLocalService getUserLocalService() {
		return userLocalService;
	}

	/**
	 * Sets the user local service.
	 *
	 * @param userLocalService the user local service
	 */
	public void setUserLocalService(
		com.liferay.portal.service.UserLocalService userLocalService) {
		this.userLocalService = userLocalService;
	}

	/**
	 * Returns the user remote service.
	 *
	 * @return the user remote service
	 */
	public com.liferay.portal.service.UserService getUserService() {
		return userService;
	}

	/**
	 * Sets the user remote service.
	 *
	 * @param userService the user remote service
	 */
	public void setUserService(
		com.liferay.portal.service.UserService userService) {
		this.userService = userService;
	}

	/**
	 * Returns the user persistence.
	 *
	 * @return the user persistence
	 */
	public UserPersistence getUserPersistence() {
		return userPersistence;
	}

	/**
	 * Sets the user persistence.
	 *
	 * @param userPersistence the user persistence
	 */
	public void setUserPersistence(UserPersistence userPersistence) {
		this.userPersistence = userPersistence;
	}

	public void afterPropertiesSet() {
		Class<?> clazz = getClass();

		_classLoader = clazz.getClassLoader();

		PersistedModelLocalServiceRegistryUtil.register("it.tref.liferay.mapit.map.model.Plugin",
			pluginLocalService);
	}

	public void destroy() {
		PersistedModelLocalServiceRegistryUtil.unregister(
			"it.tref.liferay.mapit.map.model.Plugin");
	}

	/**
	 * Returns the Spring bean ID for this bean.
	 *
	 * @return the Spring bean ID for this bean
	 */
	@Override
	public String getBeanIdentifier() {
		return _beanIdentifier;
	}

	/**
	 * Sets the Spring bean ID for this bean.
	 *
	 * @param beanIdentifier the Spring bean ID for this bean
	 */
	@Override
	public void setBeanIdentifier(String beanIdentifier) {
		_beanIdentifier = beanIdentifier;
	}

	@Override
	public Object invokeMethod(String name, String[] parameterTypes,
		Object[] arguments) throws Throwable {
		Thread currentThread = Thread.currentThread();

		ClassLoader contextClassLoader = currentThread.getContextClassLoader();

		if (contextClassLoader != _classLoader) {
			currentThread.setContextClassLoader(_classLoader);
		}

		try {
			return _clpInvoker.invokeMethod(name, parameterTypes, arguments);
		}
		finally {
			if (contextClassLoader != _classLoader) {
				currentThread.setContextClassLoader(contextClassLoader);
			}
		}
	}

	protected Class<?> getModelClass() {
		return Plugin.class;
	}

	protected String getModelClassName() {
		return Plugin.class.getName();
	}

	/**
	 * Performs an SQL query.
	 *
	 * @param sql the sql query
	 */
	protected void runSQL(String sql) throws SystemException {
		try {
			DataSource dataSource = pluginPersistence.getDataSource();

			SqlUpdate sqlUpdate = SqlUpdateFactoryUtil.getSqlUpdate(dataSource,
					sql, new int[0]);

			sqlUpdate.update();
		}
		catch (Exception e) {
			throw new SystemException(e);
		}
	}

	@BeanReference(type = it.tref.liferay.mapit.map.service.PluginLocalService.class)
	protected it.tref.liferay.mapit.map.service.PluginLocalService pluginLocalService;
	@BeanReference(type = PluginPersistence.class)
	protected PluginPersistence pluginPersistence;
	@BeanReference(type = it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalService.class)
	protected it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalService pluginPortletPreferencesLocalService;
	@BeanReference(type = PluginPortletPreferencesPersistence.class)
	protected PluginPortletPreferencesPersistence pluginPortletPreferencesPersistence;
	@BeanReference(type = com.liferay.counter.service.CounterLocalService.class)
	protected com.liferay.counter.service.CounterLocalService counterLocalService;
	@BeanReference(type = com.liferay.portal.service.ResourceLocalService.class)
	protected com.liferay.portal.service.ResourceLocalService resourceLocalService;
	@BeanReference(type = com.liferay.portal.service.UserLocalService.class)
	protected com.liferay.portal.service.UserLocalService userLocalService;
	@BeanReference(type = com.liferay.portal.service.UserService.class)
	protected com.liferay.portal.service.UserService userService;
	@BeanReference(type = UserPersistence.class)
	protected UserPersistence userPersistence;
	private String _beanIdentifier;
	private ClassLoader _classLoader;
	private PluginLocalServiceClpInvoker _clpInvoker = new PluginLocalServiceClpInvoker();
}